@@ -78,7 +78,7 @@
 #include <rtems.h>
 #include <rtems/error.h>
 #include <bsp.h>
-#include "../irq/irq.h"
+#include <bsp/irq.h>
 #include "../include/mpc5200.h"
 #include "./pcmcia_ide.h"
 
@@ -129,7 +129,7 @@ static TaskId pcmcia_ide_txTaskId;	/* SDMA TX task ID */
 #define PCMCIA_IDE_RD_SECTOR_SIZE 512   /* FIXME: make this better... */
 #define PCMCIA_IDE_WR_SECTOR_SIZE 512   /* FIXME: make this better... */
 
-boolean mpc5200_dma_task_started[2] = {FALSE,FALSE};
+bool mpc5200_dma_task_started[2] = {false,false};
 #endif /* IDE_USE_DMA */
 
 #if IDE_USE_STATISTICS
@@ -143,13 +143,13 @@ extern volatile uint32_t * mpc5200_ata_drive_regs[];
 extern uint32_t ata_pio_timings[2][6];
 
 void mpc5200_pcmciaide_dma_blockop(
-  boolean, int, uint16_t, blkdev_sg_buffer *, uint32_t *, uint32_t *);
+  bool, int, uint16_t, rtems_blkdev_sg_buffer *, uint32_t *, uint32_t *);
 /*
  * support functions for PCMCIA IDE IF
  */
-boolean mpc5200_pcmciaide_probe(int minor)
+bool mpc5200_pcmciaide_probe(int minor)
   {
-  boolean ide_card_plugged = FALSE; /* assume: we don't have a card plugged in */
+  bool ide_card_plugged = false; /* assume: we don't have a card plugged in */
   struct mpc5200_gpt *gpt = (struct mpc5200_gpt *)(&mpc5200.gpt[GPT2]);
 
   /* enable card detection on GPT2 */
@@ -158,10 +158,10 @@ boolean mpc5200_pcmciaide_probe(int minor)
 #if defined (BRS5L)
   /* Check for card detection (-CD0) */
   if((gpt->status) & GPT_STATUS_PIN)
-    ide_card_plugged = FALSE;
+    ide_card_plugged = false;
   else
 #endif
-    ide_card_plugged = TRUE;
+    ide_card_plugged = true;
 
   return ide_card_plugged;
 
@@ -243,7 +243,7 @@ static void pcmcia_ide_recv_dmairq_hdl(rtems_irq_hdl_param unused)
   bestcomm_glue_irq_disable(TASK_GEN_DP_BD_0);
 
   pcmcia_ide_rxInterrupts++; 		/* Rx int has occurred */
-      
+
   if (pcmcia_ide_hdl_task != 0) {
     rtems_event_send(pcmcia_ide_hdl_task,PCMCIA_IDE_INTERRUPT_EVENT);
   }
@@ -258,7 +258,7 @@ static void pcmcia_ide_xmit_dmairq_hdl(rtems_irq_hdl_param unused)
   bestcomm_glue_irq_disable(TASK_GEN_DP_BD_1);
 
   pcmcia_ide_txInterrupts++; 		/* Tx int has occurred */
-      
+
   if (pcmcia_ide_hdl_task != 0) {
     rtems_event_send(pcmcia_ide_hdl_task,PCMCIA_IDE_INTERRUPT_EVENT);
   }
@@ -279,7 +279,7 @@ void mpc5200_pcmciaide_dma_init(int minor)
   rxParam.NumBD        = PCMCIA_IDE_DMA_RD_BD_CNT;
   rxParam.Size.MaxBuf  = PCMCIA_IDE_RD_SECTOR_SIZE;
   rxParam.Initiator    = INITIATOR_ALWAYS;
-  rxParam.StartAddrSrc = 
+  rxParam.StartAddrSrc =
     (uint32)mpc5200_ata_drive_regs[IDE_REGISTER_DATA_WORD];
   rxParam.IncrSrc      = 0;
   rxParam.SzSrc	       = sizeof(uint16_t);
@@ -302,7 +302,7 @@ void mpc5200_pcmciaide_dma_init(int minor)
     (uint32)mpc5200_ata_drive_regs[IDE_REGISTER_DATA_WORD];
   txParam.IncrDst      = 0;
   txParam.SzDst        = sizeof(uint16_t);
-  
+
   pcmcia_ide_txTaskId  = TaskSetup( TASK_GEN_DP_BD_1, &txParam );
   /*
    * FIXME: Init BD rings
@@ -313,21 +313,21 @@ void mpc5200_pcmciaide_dma_init(int minor)
    */
   /*
    * connect interrupt handlers
-   */  
+   */
   bestcomm_glue_irq_install(TASK_GEN_DP_BD_1,pcmcia_ide_xmit_dmairq_hdl,NULL);
   bestcomm_glue_irq_install(TASK_GEN_DP_BD_0,pcmcia_ide_recv_dmairq_hdl,NULL);
 }
 
-void mpc5200_pcmciaide_dma_blockop(boolean is_write,
-				   int minor, 
-				   uint16_t block_size, 
-				   blkdev_sg_buffer *bufs,
-				   uint32_t *cbuf, 
+void mpc5200_pcmciaide_dma_blockop(bool is_write,
+				   int minor,
+				   uint16_t block_size,
+				   rtems_blkdev_sg_buffer *bufs,
+				   uint32_t *cbuf,
 				   uint32_t *pos)
 
 {
   /*
-   * Nameing: 
+   * Nameing:
    * - a block is one unit of data on disk (multiple sectors)
    * - a buffer is a contignuous chunk of data in memory
    * a block on disk may be filled with data from several buffers
@@ -338,7 +338,7 @@ void mpc5200_pcmciaide_dma_blockop(boolean is_write,
   rtems_status_code rc = RTEMS_SUCCESSFUL;
   rtems_event_set events;
   BDIdx nxt_bd_idx;
-  boolean use_irq = (_System_state_Current == SYSTEM_STATE_UP);
+  bool use_irq = (_System_state_Current == SYSTEM_STATE_UP);
   /*
    * determine number of blocks
    */
@@ -360,16 +360,16 @@ void mpc5200_pcmciaide_dma_blockop(boolean is_write,
    */
   while ((rc == RTEMS_SUCCESSFUL) &&
 	 (bufs_from_dma < bufs_total)) {
-    
-    while ((rc == RTEMS_SUCCESSFUL) && 
-	   (bufs_to_dma < bufs_total) && 
+
+    while ((rc == RTEMS_SUCCESSFUL) &&
+	   (bufs_to_dma < bufs_total) &&
 	   (bds_free > 0)) {
       /*
        * fill in BD, set interrupt if needed
        */
     SDMA_CLEAR_IEVENT(&mpc5200.IntPend,(is_write
 	                                  ? TASK_GEN_DP_BD_1
-	                                  : TASK_GEN_DP_BD_0));	
+	                                  : TASK_GEN_DP_BD_0));
       if (is_write) {
 	TaskBDAssign(pcmcia_ide_txTaskId ,
 		     (void *)bufs[bufs_to_dma].buffer,
@@ -394,7 +394,7 @@ void mpc5200_pcmciaide_dma_blockop(boolean is_write,
       bds_free    --;
     }
     if (is_write) {
-      TaskStart( pcmcia_ide_txTaskId, TASK_AUTOSTART_DISABLE, 
+      TaskStart( pcmcia_ide_txTaskId, TASK_AUTOSTART_DISABLE,
 		 pcmcia_ide_txTaskId, TASK_INTERRUPT_DISABLE );
     }
     else {
@@ -407,12 +407,12 @@ void mpc5200_pcmciaide_dma_blockop(boolean is_write,
        * enable interrupts, wait for interrupt event
        */
       rtems_task_ident(RTEMS_SELF,0,(rtems_id *)&pcmcia_ide_hdl_task);
-      bestcomm_glue_irq_enable((is_write 
-				? TASK_GEN_DP_BD_1 
+      bestcomm_glue_irq_enable((is_write
+				? TASK_GEN_DP_BD_1
 				: TASK_GEN_DP_BD_0));
 
-      rtems_event_receive(PCMCIA_IDE_INTERRUPT_EVENT, 
-			  RTEMS_WAIT | RTEMS_EVENT_ANY, 
+      rtems_event_receive(PCMCIA_IDE_INTERRUPT_EVENT,
+			  RTEMS_WAIT | RTEMS_EVENT_ANY,
 			  RTEMS_NO_TIMEOUT, &events);
 
       pcmcia_ide_hdl_task = 0;
@@ -429,13 +429,13 @@ void mpc5200_pcmciaide_dma_blockop(boolean is_write,
     }
 
     do {
-	  nxt_bd_idx = TaskBDRelease(is_write 
-	   				             ? pcmcia_ide_txTaskId 
+	  nxt_bd_idx = TaskBDRelease(is_write
+	   				             ? pcmcia_ide_txTaskId
 					             : pcmcia_ide_rxTaskId);
       if ((nxt_bd_idx != TASK_ERR_BD_RING_EMPTY) &&
           (nxt_bd_idx != TASK_ERR_BD_BUSY)) {
-        (*cbuf)++;      
-        (*pos) += bufs[bufs_from_dma].length;      
+        (*cbuf)++;
+        (*pos) += bufs[bufs_from_dma].length;
         bufs_from_dma++;
 	  }
     } while ((nxt_bd_idx != TASK_ERR_BD_RING_EMPTY) &&
@@ -446,7 +446,7 @@ void mpc5200_pcmciaide_dma_blockop(boolean is_write,
 #endif /* IDE_USE_DMA */
 
 
-void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buffer *bufs,
+void mpc5200_pcmciaide_read_block(int minor, uint32_t block_size, rtems_blkdev_sg_buffer *bufs,
                                   uint32_t *cbuf, uint32_t *pos)
 {
 
@@ -454,8 +454,8 @@ void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buff
   uint16_t  cnt = 0;
   uint16_t *lbuf = (uint16_t*)((uint8_t*)(bufs[(*cbuf)].buffer)+(*pos));
   uint32_t  llength = bufs[(*cbuf)].length;
-  boolean use_dma;
-  
+  bool      use_dma;
+
 #if IDE_USE_STATISTICS
       mpc5200_pcmciaide_read_block_call_cnt++;
 #endif
@@ -465,10 +465,10 @@ void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buff
    * then do not use DMA
    * Is this needed?
    */
-  use_dma = TRUE;
-  /* use_dma = FALSE; */
+  use_dma = true;
+  /* use_dma = false; */
 #else
-  use_dma = FALSE;
+  use_dma = false;
 #endif
   if (use_dma) {
     /*
@@ -477,7 +477,7 @@ void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buff
      * type of transfer mode
      */
     while ((GET_UP_BYTE_OF_MPC5200_ATA_DRIVE_REG((volatile uint32_t)
-						 (mpc5200.ata_dctr_dasr)) & 
+						 (mpc5200.ata_dctr_dasr)) &
 	    IDE_REGISTER_STATUS_DRQ) == 0);
     /*
      * translate (part of) buffer list into DMA BDs
@@ -495,14 +495,14 @@ void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buff
       *lbuf++ = GET_UP_WORD_OF_MPC5200_ATA_DRIVE_REG(*(volatile uint32_t *)(ata_reg)); /* only 16 bit data port */
       cnt += 2;
       (*pos) += 2;
-      
+
       if((*pos) == llength) {
-	  
+
 	  (*pos) = 0;
 	  (*cbuf)++;
 	  lbuf = bufs[(*cbuf)].buffer;
 	  llength = bufs[(*cbuf)].length;
-	  
+
       }
     }
 #else
@@ -512,12 +512,12 @@ void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buff
       *lbuf++ = *(volatile uint16_t *)(ata_reg); /* only 16 bit data port */
       cnt += 2;
       (*pos) += 2;
-      
+
       if((*pos) == llength) {
 	(*pos) = 0;
 	(*cbuf)++;
 	lbuf = bufs[(*cbuf)].buffer;
-	llength = bufs[(*cbuf)].length;	
+	llength = bufs[(*cbuf)].length;
       }
     }
 #endif
@@ -525,19 +525,19 @@ void mpc5200_pcmciaide_read_block(int minor, uint16_t block_size, blkdev_sg_buff
       *lbuf++ = 0; /* fill buffer with dummy data */
       cnt += 2;
       (*pos) += 2;
-      
+
       if((*pos) == llength) {
 	(*pos) = 0;
 	(*cbuf)++;
 	lbuf = bufs[(*cbuf)].buffer;
-	llength = bufs[(*cbuf)].length;	
+	llength = bufs[(*cbuf)].length;
       }
     }
   }
 }
 
-void mpc5200_pcmciaide_write_block(int minor, uint16_t block_size,
-                                   blkdev_sg_buffer *bufs, uint32_t *cbuf,
+void mpc5200_pcmciaide_write_block(int minor, uint32_t block_size,
+                                   rtems_blkdev_sg_buffer *bufs, uint32_t *cbuf,
                                    uint32_t *pos)
 
 {
@@ -547,7 +547,7 @@ void mpc5200_pcmciaide_write_block(int minor, uint16_t block_size,
   uint16_t  cnt = 0;
   uint16_t *lbuf = (uint16_t *)((uint8_t *)(bufs[(*cbuf)].buffer) + (*pos));
   uint32_t  llength = bufs[(*cbuf)].length;
-  boolean use_dma;
+  bool use_dma;
 
 #if IDE_USE_STATISTICS
   mpc5200_pcmciaide_write_block_call_cnt++;
@@ -558,9 +558,9 @@ void mpc5200_pcmciaide_write_block(int minor, uint16_t block_size,
    * then do not use DMA
    * Is this needed?
    */
-  use_dma = TRUE;
+  use_dma = true;
 #else
-  use_dma = FALSE;
+  use_dma = false;
 #endif
 
   if (use_dma) {
@@ -570,14 +570,14 @@ void mpc5200_pcmciaide_write_block(int minor, uint16_t block_size,
      * type of transfer mode
      */
     while ((GET_UP_BYTE_OF_MPC5200_ATA_DRIVE_REG((volatile uint32_t)
-						 (mpc5200.ata_dctr_dasr)) & 
+						 (mpc5200.ata_dctr_dasr)) &
 	    IDE_REGISTER_STATUS_DRQ) == 0);
     /*
      * translate (part of) buffer list into DMA BDs
      * only last (available) DMA BD sends interrupt
      * DMA BDs may get ready as soon as possible
      */
-    mpc5200_pcmciaide_dma_blockop(TRUE, /* write opeartion */
+    mpc5200_pcmciaide_dma_blockop(true, /* write opeartion */
 				  minor,
 				  block_size,bufs,cbuf,pos);
   }
@@ -595,28 +595,28 @@ void mpc5200_pcmciaide_write_block(int minor, uint16_t block_size,
 	loop_max = (block_size - cnt);
       }
       for (loop_cnt = loop_max/2;loop_cnt > 0;loop_cnt--) {
-	*(volatile uint32_t *)(ata_reg) = 
+	*(volatile uint32_t *)(ata_reg) =
 	  SET_UP_WORD_OF_MPC5200_ATA_DRIVE_REG(*lbuf++); /* only 16 bit data port */
       }
       cnt += loop_max;
       (*pos) += loop_max;
-      
+
       if((*pos) == llength) {
-	
+
 	(*pos) = 0;
 	(*cbuf)++;
 	lbuf = bufs[(*cbuf)].buffer;
-	llength = bufs[(*cbuf)].length;	
+	llength = bufs[(*cbuf)].length;
       }
     }
 #else
-    while((GET_UP_BYTE_OF_MPC5200_ATA_DRIVE_REG((volatile uint32_t)(mpc5200.ata_dctr_dasr)) 
-	   & IDE_REGISTER_STATUS_DRQ) 
+    while((GET_UP_BYTE_OF_MPC5200_ATA_DRIVE_REG((volatile uint32_t)(mpc5200.ata_dctr_dasr))
+	   & IDE_REGISTER_STATUS_DRQ)
 	  && (cnt < block_size)) {
       *(volatile uint16_t *)(ata_reg) = *lbuf++; /* only 16 bit data port */
       cnt += 2;
       (*pos) += 2;
-      
+
       if((*pos) == llength) {
 	(*pos) = 0;
 	(*cbuf)++;
@@ -657,7 +657,7 @@ void mpc5200_pcmciaide_initialize(int minor)
 
 #if IDE_USE_DMA
   mpc5200_pcmciaide_dma_init(minor);
-#endif  
+#endif
   }
 
 
