@@ -6,21 +6,20 @@
  *  and deadlock when two tasks poll for the same lock.
  *  previous level.
  *
- *  COPYRIGHT (c) 1989-1997.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may in
  *  the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: lock.c,v 1.5 2004/04/15 13:26:18 ralf Exp $
+ *  $Id$
  */
 
 #include <rtems.h>
 #include <bsp.h>
 #include <shm_driver.h>
-
-typedef volatile unsigned int volint;
+#include <psim.h>
 
 /*
  *  Shm_Initialize_lock
@@ -42,13 +41,14 @@ void Shm_Initialize_lock(
  *  a deadlock condition.
  */
 
+static rtems_interrupt_level level;
+
 void Shm_Lock(
   Shm_Locked_queue_Control *lq_cb
 )
 {
-  volint *p = (volint *)0xc0010000;
-
-  (void) p[1];
+  rtems_interrupt_disable( level );
+    (void) PSIM.Semaphore.lock;
 }
 
 /*
@@ -61,7 +61,6 @@ void Shm_Unlock(
   Shm_Locked_queue_Control *lq_cb
 )
 {
-  volint *p = (volint *)0xc0010000;
-
-  (void) p[2];
+    (void) PSIM.Semaphore.unlock;
+  rtems_interrupt_enable( level );
 }
