@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: m68kidle.c,v 1.2 2003/09/04 18:53:04 joel Exp $
+ *  $Id$
  */
 
 #include <rtems/system.h>
@@ -17,7 +17,7 @@
 
 /*PAGE
  *
- *  _Thread_Idle_body
+ *  _CPU_Thread_Idle_body
  *
  *  This kernel routine is the idle thread.  The idle thread runs any time
  *  no other thread is ready to run.  This thread loops forever with
@@ -28,8 +28,8 @@
  *
  *  Output parameters:  NONE
  */
- 
-void _CPU_Thread_Idle_body( void )
+
+void *_CPU_Thread_Idle_body( uintptr_t ignored )
 {
 #if defined(mcf5272)
   for( ; ; ) {
@@ -38,6 +38,6 @@ void _CPU_Thread_Idle_body( void )
   }
 #else
   for( ; ; )
-    asm volatile( "stop #0x3000" );  /* supervisor mode, all interrupts on */
+    asm volatile( "stop #0x3000":::"cc" );  /* supervisor mode, all interrupts on */
 #endif
 }
