@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: cre_mpf.c,v 1.1 2007/04/17 20:32:12 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -22,8 +22,8 @@
  */
 
 ER cre_mpf(
-  ID      mpfid,
-  T_CMPF *pk_cmpf
+  ID      mpfid __attribute__((unused)),
+  T_CMPF *pk_cmpf __attribute__((unused))
 )
 {
   return E_OK;
