@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: utime.c,v 1.11 2003/09/04 18:54:13 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -30,7 +30,7 @@ int utime(
   rtems_filesystem_location_info_t   temp_loc;
   int                                result;
 
-  if ( rtems_filesystem_evaluate_path( path, 0x00, &temp_loc, TRUE ) )
+  if ( rtems_filesystem_evaluate_path( path, strlen( path ), 0x00, &temp_loc, true ) )
     return -1;
 
   if ( !temp_loc.ops->utime_h ){
