@@ -6,10 +6,12 @@
  * Copyright (C) 2001 OKTET Ltd., St.-Petersburg, Russia
  * Author: Eugeny S. Mints <Eugeny.Mints@oktet.ru>
  *
- * @(#) $Id: fat_file.c,v 1.11 2005/05/06 14:57:43 joel Exp $
+ * @(#) $Id$
  *
  */
 
+#define MSDOS_TRACE 1
+
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -31,23 +33,23 @@
 #include "fat_file.h"
 
 static inline void
-_hash_insert(Chain_Control *hash, uint32_t   key1, uint32_t   key2,
+_hash_insert(rtems_chain_control *hash, uint32_t   key1, uint32_t   key2,
              fat_file_fd_t *el);
 
 static inline void
-_hash_delete(Chain_Control *hash, uint32_t   key1, uint32_t   key2,
+_hash_delete(rtems_chain_control *hash, uint32_t   key1, uint32_t   key2,
              fat_file_fd_t *el);
 
 static inline int
 _hash_search(
     rtems_filesystem_mount_table_entry_t  *mt_entry,
-    Chain_Control                         *hash,
+    rtems_chain_control                   *hash,
     uint32_t                               key1,
     uint32_t                               key2,
-    fat_file_fd_t			   **ret
+    fat_file_fd_t			                   **ret
 );
 
-static int
+static off_t
 fat_file_lseek(
     rtems_filesystem_mount_table_entry_t  *mt_entry,
     fat_file_fd_t                         *fat_fd,
@@ -73,8 +75,7 @@ fat_file_lseek(
  *
  * PARAMETERS:
  *     mt_entry - mount table entry
- *     cln      - cluster num of the node
- *     ofs      - offset of the node
+ *     pos      - cluster and offset of the node
  *     fat_fd   - placeholder for returned fat-file descriptor
  *
  * RETURNS:
@@ -84,8 +85,7 @@ fat_file_lseek(
 int
 fat_file_open(
     rtems_filesystem_mount_table_entry_t  *mt_entry,
-    uint32_t                               cln,
-    uint32_t                               ofs,
+    fat_dir_pos_t                         *dir_pos,
     fat_file_fd_t                        **fat_fd
     )
 {
@@ -95,7 +95,7 @@ fat_file_open(
     uint32_t       key = 0;
 
     /* construct key */
-    key = fat_construct_key(mt_entry, cln, ofs);
+    key = fat_construct_key(mt_entry, &dir_pos->sname);
 
     /* access "valid" hash table */
     rc = _hash_search(mt_entry, fs_info->vhash, key, 0, &lfat_fd);
@@ -112,12 +112,16 @@ fat_file_open(
 
     lfat_fd = (*fat_fd) = (fat_file_fd_t*)malloc(sizeof(fat_file_fd_t));
     if ( lfat_fd == NULL )
-        set_errno_and_return_minus_one( ENOMEM );
+        rtems_set_errno_and_return_minus_one( ENOMEM );
+
+    memset(lfat_fd, 0, sizeof(fat_file_fd_t));
 
     lfat_fd->links_num = 1;
     lfat_fd->flags &= ~FAT_FILE_REMOVED;
     lfat_fd->map.last_cln = FAT_UNDEFINED_VALUE;
 
+    lfat_fd->dir_pos = *dir_pos;
+
     if ( rc != RC_OK )
         lfat_fd->ino = key;
     else
@@ -131,12 +135,11 @@ fat_file_open(
              * XXX: kernel resource is unsufficient, but not the memory,
              * but there is no suitable errno :(
              */
-            set_errno_and_return_minus_one( ENOMEM );
+            rtems_set_errno_and_return_minus_one( ENOMEM );
         }
     }
     _hash_insert(fs_info->vhash, key, lfat_fd->ino, lfat_fd);
 
-
     /*
      * other fields of fat-file descriptor will be initialized on upper
      * level
@@ -201,7 +204,7 @@ fat_file_close(
         return rc;
     }
 
-    key = fat_construct_key(mt_entry, fat_fd->info_cln, fat_fd->info_ofs);
+    key = fat_construct_key(mt_entry, &fat_fd->dir_pos.sname);
 
     if (fat_fd->flags & FAT_FILE_REMOVED)
     {
@@ -383,11 +386,11 @@ fat_file_write(
         return cmpltd;
 
     if ( start > fat_fd->fat_file_size )
-        set_errno_and_return_minus_one( EIO );
+        rtems_set_errno_and_return_minus_one( EIO );
 
     if ((count > fat_fd->size_limit) ||
         (start > fat_fd->size_limit - count))
-        set_errno_and_return_minus_one( EIO );
+        rtems_set_errno_and_return_minus_one( EIO );
 
     rc = fat_file_extend(mt_entry, fat_fd, start + count, &c);
     if (rc != RC_OK)
@@ -493,7 +496,7 @@ fat_file_extend(
 
     if ((FAT_FD_OF_ROOT_DIR(fat_fd)) &&
         (fs_info->vol.type & (FAT_FAT12 | FAT_FAT16)))
-        set_errno_and_return_minus_one( ENOSPC );
+        rtems_set_errno_and_return_minus_one( ENOSPC );
 
     bytes_remain = (fs_info->vol.bpc -
                    (fat_fd->fat_file_size & (fs_info->vol.bpc - 1))) &
@@ -525,7 +528,7 @@ fat_file_extend(
 
     /* this means that no space left on device */
     if ((cls_added == 0) && (bytes_remain == 0))
-        set_errno_and_return_minus_one(ENOSPC);
+        rtems_set_errno_and_return_minus_one(ENOSPC);
 
     /*  check wether we satisfied request for 'cls2add' clusters */
     if (cls2add != cls_added)
@@ -580,6 +583,8 @@ fat_file_extend(
         }
     }
 
+    fat_fd->fat_file_size = new_length;
+
     return RC_OK;
 }
 
@@ -687,7 +692,7 @@ fat_file_ioctl(
 
             /* sanity check */
             if ( pos >= fat_fd->fat_file_size )
-                set_errno_and_return_minus_one( EIO );
+                rtems_set_errno_and_return_minus_one( EIO );
 
             if ((FAT_FD_OF_ROOT_DIR(fat_fd)) &&
                 (fs_info->vol.type & (FAT_FAT12 | FAT_FAT16)))
@@ -734,7 +739,7 @@ fat_file_mark_removed(
     fat_fs_info_t *fs_info = mt_entry->fs_info;
     uint32_t       key = 0;
 
-    key = fat_construct_key(mt_entry, fat_fd->info_cln, fat_fd->info_ofs);
+    key = fat_construct_key(mt_entry, &fat_fd->dir_pos.sname);
 
     _hash_delete(fs_info->vhash, key, fat_fd->ino, fat_fd);
 
@@ -759,13 +764,13 @@ fat_file_datasync(
     fat_file_fd_t                        *fat_fd
     )
 {
-    int                rc = RC_OK;
-    rtems_status_code  sc = RTEMS_SUCCESSFUL;
-    fat_fs_info_t     *fs_info = mt_entry->fs_info;
-    uint32_t           cur_cln = fat_fd->cln;
-    bdbuf_buffer      *block = NULL;
-    uint32_t           sec = 0;
-    uint32_t           i = 0;
+    int                 rc = RC_OK;
+    rtems_status_code   sc = RTEMS_SUCCESSFUL;
+    fat_fs_info_t      *fs_info = mt_entry->fs_info;
+    uint32_t            cur_cln = fat_fd->cln;
+    rtems_bdbuf_buffer *block = NULL;
+    uint32_t            sec = 0;
+    uint32_t            i = 0;
 
     if (fat_fd->fat_file_size == 0)
         return RC_OK;
@@ -788,11 +793,11 @@ fat_file_datasync(
             /* ... sync it */
             sc = rtems_bdbuf_read(fs_info->vol.dev, (sec + i), &block);
             if (sc != RTEMS_SUCCESSFUL)
-                set_errno_and_return_minus_one( EIO );
+                rtems_set_errno_and_return_minus_one( EIO );
 
             sc = rtems_bdbuf_sync(block);
             if ( sc != RTEMS_SUCCESSFUL )
-                set_errno_and_return_minus_one( EIO );
+                rtems_set_errno_and_return_minus_one( EIO );
         }
 
         rc = fat_get_fat_cluster(mt_entry, cur_cln, &cur_cln);
@@ -867,10 +872,10 @@ fat_file_size(
  *     None
  */
 static inline void
-_hash_insert(Chain_Control *hash, uint32_t   key1, uint32_t   key2,
+_hash_insert(rtems_chain_control *hash, uint32_t   key1, uint32_t   key2,
              fat_file_fd_t *el)
 {
-    _Chain_Append((hash) + ((key1) % FAT_HASH_MODULE), &(el)->link);
+    rtems_chain_append((hash) + ((key1) % FAT_HASH_MODULE), &(el)->link);
 }
 
 
@@ -887,10 +892,10 @@ _hash_insert(Chain_Control *hash, uint32_t   key1, uint32_t   key2,
  *     None
  */
 static inline void
-_hash_delete(Chain_Control *hash, uint32_t   key1, uint32_t   key2,
+_hash_delete(rtems_chain_control *hash, uint32_t   key1, uint32_t   key2,
              fat_file_fd_t *el)
 {
-    _Chain_Extract(&(el)->link);
+    rtems_chain_extract(&(el)->link);
 }
 
 /* _hash_search --
@@ -910,20 +915,19 @@ _hash_delete(Chain_Control *hash, uint32_t   key1, uint32_t   key2,
 static inline int
 _hash_search(
     rtems_filesystem_mount_table_entry_t  *mt_entry,
-    Chain_Control                         *hash,
+    rtems_chain_control                   *hash,
     uint32_t                               key1,
     uint32_t                               key2,
     fat_file_fd_t                          **ret
     )
 {
-    uint32_t   mod = (key1) % FAT_HASH_MODULE;
-    Chain_Node *the_node = ((Chain_Control *)((hash) + mod))->first;
+    uint32_t          mod = (key1) % FAT_HASH_MODULE;
+    rtems_chain_node *the_node = ((rtems_chain_control *)((hash) + mod))->first;
 
-    for ( ; !_Chain_Is_tail((hash) + mod, the_node) ; )
+    for ( ; !rtems_chain_is_tail((hash) + mod, the_node) ; )
     {
         fat_file_fd_t *ffd = (fat_file_fd_t *)the_node;
-        uint32_t   ck =
-                fat_construct_key(mt_entry, ffd->info_cln, ffd->info_ofs);
+        uint32_t       ck =  fat_construct_key(mt_entry, &ffd->dir_pos.sname);
 
         if ( (key1) == ck)
         {
@@ -938,7 +942,7 @@ _hash_search(
     return -1;
 }
 
-static int
+static off_t
 fat_file_lseek(
     rtems_filesystem_mount_table_entry_t  *mt_entry,
     fat_file_fd_t                         *fat_fd,
@@ -947,9 +951,7 @@ fat_file_lseek(
     )
 {
     int rc = RC_OK;
-/*
-    assert(fat_fd->fat_file_size);
- */
+
     if (file_cln == fat_fd->map.file_cln)
         *disk_cln = fat_fd->map.disk_cln;
     else
