@@ -1,6 +1,6 @@
 /*
   ------------------------------------------------------------------------
-  $Id: capture-cli.c,v 1.16 2007/08/17 00:54:16 ccj Exp $
+  $Id$
   ------------------------------------------------------------------------
 
   Copyright Objective Design Systems Pty Ltd, 2002
@@ -65,11 +65,11 @@ static const char* open_usage = "usage: copen [-i] size\n";
 static void
 rtems_capture_cli_open (int                          argc,
                         char**                       argv,
-                        rtems_monitor_command_arg_t* command_arg,
-                        boolean                      verbose)
+                        const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                        bool                         verbose __attribute__((unused)))
 {
   uint32_t          size = 0;
-  rtems_boolean     enable = 0;
+  bool              enable = false;
   rtems_status_code sc;
   int               arg;
 
@@ -84,7 +84,7 @@ rtems_capture_cli_open (int                          argc,
     if (argv[arg][0] == '-')
     {
       if (argv[arg][1] == 'i')
-        enable = 1;
+        enable = true;
       else
         fprintf (stdout, "warning: option -%c ignored\n", argv[arg][1]);
     }
@@ -134,10 +134,10 @@ rtems_capture_cli_open (int                          argc,
  */
 
 static void
-rtems_capture_cli_close (int                          argc,
-                         char**                       argv,
-                         rtems_monitor_command_arg_t* command_arg,
-                         boolean                      verbose)
+rtems_capture_cli_close (int                          argc __attribute__((unused)),
+                         char**                       argv __attribute__((unused)),
+                         const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                         bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
 
@@ -162,10 +162,10 @@ rtems_capture_cli_close (int                          argc,
  */
 
 static void
-rtems_capture_cli_enable (int                          argc,
-                          char**                       argv,
-                          rtems_monitor_command_arg_t* command_arg,
-                          boolean                      verbose)
+rtems_capture_cli_enable (int                          argc __attribute__((unused)),
+                          char**                       argv __attribute__((unused)),
+                          const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                          bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
 
@@ -190,10 +190,10 @@ rtems_capture_cli_enable (int                          argc,
  */
 
 static void
-rtems_capture_cli_disable (int                          argc,
-                           char**                       argv,
-                           rtems_monitor_command_arg_t* command_arg,
-                           boolean                      verbose)
+rtems_capture_cli_disable (int                          argc __attribute__((unused)),
+                           char**                       argv __attribute__((unused)),
+                           const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                           bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
 
@@ -218,10 +218,10 @@ rtems_capture_cli_disable (int                          argc,
  */
 
 static void
-rtems_capture_cli_task_list (int                          argc,
-                             char**                       argv,
-                             rtems_monitor_command_arg_t* command_arg,
-                             boolean                      verbose)
+rtems_capture_cli_task_list (int                          argc __attribute__((unused)),
+                             char**                       argv __attribute__((unused)),
+                             const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                             bool                         verbose __attribute__((unused)))
 {
   rtems_task_priority   ceiling = rtems_capture_watch_get_ceiling ();
   rtems_task_priority   floor = rtems_capture_watch_get_floor ();
@@ -306,12 +306,12 @@ rtems_capture_cli_task_list (int                          argc,
  */
 
 static void
-rtems_capture_cli_task_load_thread (rtems_task_argument arg)
+rtems_capture_cli_task_load_thread (rtems_task_argument arg __attribute__((unused)))
 {
   rtems_task_priority ceiling = rtems_capture_watch_get_ceiling ();
   rtems_task_priority floor = rtems_capture_watch_get_floor ();
   int                 last_count = 0;
-  
+
   for (;;)
   {
     rtems_capture_task_t* tasks[RTEMS_CAPTURE_CLI_MAX_LOAD_TASKS + 1];
@@ -431,19 +431,19 @@ rtems_capture_cli_task_load_thread (rtems_task_argument arg)
 
     if (count < RTEMS_CAPTURE_CLI_MAX_LOAD_TASKS)
     {
-      j = RTEMS_CAPTURE_CLI_MAX_LOAD_TASKS - count;   
+      j = RTEMS_CAPTURE_CLI_MAX_LOAD_TASKS - count;
       while (j > 0)
       {
         fprintf (stdout, "\x1b[K\n");
         j--;
       }
     }
-    
+
     last_count = count;
 
     cli_load_thread_active = 0;
 
-    rtems_task_wake_after (TOD_MICROSECONDS_TO_TICKS (5000000));
+    rtems_task_wake_after (RTEMS_MICROSECONDS_TO_TICKS (5000000));
   }
 }
 
@@ -457,10 +457,10 @@ rtems_capture_cli_task_load_thread (rtems_task_argument arg)
  */
 
 static void
-rtems_capture_cli_task_load (int                          argc,
-                             char**                       argv,
-                             rtems_monitor_command_arg_t* command_arg,
-                             boolean                      verbose)
+rtems_capture_cli_task_load (int                          argc __attribute__((unused)),
+                             char**                       argv __attribute__((unused)),
+                             const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                             bool                         verbose __attribute__((unused)))
 {
   rtems_status_code   sc;
   rtems_task_priority priority;
@@ -477,13 +477,13 @@ rtems_capture_cli_task_load (int                          argc,
   }
 
   name = rtems_build_name('C', 'P', 'l', 't');
-  
+
   sc = rtems_task_create (name, priority, 4 * 1024,
                           RTEMS_NO_FLOATING_POINT | RTEMS_LOCAL,
                           RTEMS_PREEMPT | RTEMS_TIMESLICE | RTEMS_NO_ASR,
                           &id);
-  
-  if (sc != RTEMS_SUCCESSFUL) 
+
+  if (sc != RTEMS_SUCCESSFUL)
   {
     fprintf (stdout, "error: cannot create helper thread: %s\n",
              rtems_status_text (sc));
@@ -509,7 +509,7 @@ rtems_capture_cli_task_load (int                          argc,
       int loops = 20;
 
       while (loops && cli_load_thread_active)
-        rtems_task_wake_after (TOD_MICROSECONDS_TO_TICKS (100000));
+        rtems_task_wake_after (RTEMS_MICROSECONDS_TO_TICKS (100000));
 
       rtems_task_delete (id);
 
@@ -530,10 +530,10 @@ rtems_capture_cli_task_load (int                          argc,
  */
 
 static void
-rtems_capture_cli_watch_list (int                          argc,
-                              char**                       argv,
-                              rtems_monitor_command_arg_t* command_arg,
-                              boolean                      verbose)
+rtems_capture_cli_watch_list (int                          argc __attribute__((unused)),
+                              char**                       argv __attribute__((unused)),
+                              const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                              bool                         verbose __attribute__((unused)))
 {
   rtems_capture_control_t* control = rtems_capture_get_control_list ();
   rtems_task_priority      ceiling = rtems_capture_watch_get_ceiling ();
@@ -619,10 +619,10 @@ rtems_capture_cli_watch_list (int                          argc,
  *
  */
 
-static rtems_boolean
+static bool
 rtems_capture_cli_get_name_id (char*          arg,
-                               rtems_boolean* valid_name,
-                               rtems_boolean* valid_id,
+                               bool*          valid_name,
+                               bool*          valid_id,
                                rtems_name*    name,
                                rtems_id*      id)
 {
@@ -642,13 +642,13 @@ rtems_capture_cli_get_name_id (char*          arg,
   l = strlen (arg);
 
   for (i = 0; i < l; i++)
-    if (!isxdigit (arg[i]))
+    if (!isxdigit ((unsigned char)arg[i]))
       break;
 
   if (i == l)
   {
     *id = strtoul (arg, 0, 16);
-    *valid_id = 1;
+    *valid_id = true;
   }
   else
   {
@@ -659,13 +659,11 @@ rtems_capture_cli_get_name_id (char*          arg,
      * @warning The extra assigns play with the byte order so do not
      *          remove unless the score has been updated.
      */
-    Objects_Name object_name;
     rtems_name   rname;
-    
+
     rname = rtems_build_name(arg[0], arg[1], arg[2], arg[3]);
-    object_name = (Objects_Name) rname;
-    *name = (rtems_name) object_name;
-    *valid_name = 1;
+    *name = rname;
+    *valid_name = true;
   }
 
   return 1;
@@ -686,15 +684,15 @@ static char const * watch_add_usage = "usage: cwadd [task name] [id]\n";
 static void
 rtems_capture_cli_watch_add (int                          argc,
                              char**                       argv,
-                             rtems_monitor_command_arg_t* command_arg,
-                             boolean                      verbose)
+                             const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                             bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
   int               arg;
   rtems_name        name = 0;
   rtems_id          id = 0;
-  rtems_boolean     valid_name = 0;
-  rtems_boolean     valid_id = 0;
+  bool              valid_name = false;
+  bool              valid_id = false;
 
   if (argc <= 1)
   {
@@ -749,15 +747,15 @@ static char const * watch_del_usage = "usage: cwdel [task name] [id]\n";
 static void
 rtems_capture_cli_watch_del (int                          argc,
                              char**                       argv,
-                             rtems_monitor_command_arg_t* command_arg,
-                             boolean                      verbose)
+                             const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                             bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
   int               arg;
   rtems_name        name = 0;
   rtems_id          id = 0;
-  rtems_boolean     valid_name = 0;
-  rtems_boolean     valid_id = 0;
+  bool              valid_name = false;
+  bool              valid_id = false;
 
   if (argc <= 1)
   {
@@ -811,16 +809,16 @@ static char const * watch_control_usage = "usage: cwctl [task name] [id] on/off\
 static void
 rtems_capture_cli_watch_control (int                          argc,
                                  char**                       argv,
-                                 rtems_monitor_command_arg_t* command_arg,
-                                 boolean                      verbose)
+                                 const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                                 bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
   int               arg;
   rtems_name        name = 0;
   rtems_id          id = 0;
-  rtems_boolean     valid_name = 0;
-  rtems_boolean     valid_id = 0;
-  rtems_boolean     enable = 0;
+  bool              valid_name = false;
+  bool              valid_id = false;
+  bool              enable = false;
 
   if (argc <= 2)
   {
@@ -837,9 +835,9 @@ rtems_capture_cli_watch_control (int                          argc,
     else
     {
       if (strcmp (argv[arg], "on") == 0)
-        enable = 1;
+        enable = true;
       else if (strcmp (argv[arg], "off") == 0)
-        enable = 0;
+        enable = false;
       else if (!rtems_capture_cli_get_name_id (argv[arg], &valid_name,
                                                &valid_id, &name, &id))
         return;
@@ -878,12 +876,12 @@ static char const * watch_global_usage = "usage: cwglob on/off\n";
 static void
 rtems_capture_cli_watch_global (int                          argc,
                                 char**                       argv,
-                                rtems_monitor_command_arg_t* command_arg,
-                                boolean                      verbose)
+                                const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                                bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
   int               arg;
-  rtems_boolean     enable = 0;
+  bool              enable = false;
 
   if (argc <= 1)
   {
@@ -900,9 +898,9 @@ rtems_capture_cli_watch_global (int                          argc,
     else
     {
       if (strcmp (argv[arg], "on") == 0)
-        enable = 1;
+        enable = true;
       else if (strcmp (argv[arg], "off") == 0)
-        enable = 0;
+        enable = false;
     }
   }
 
@@ -932,8 +930,8 @@ static char const * watch_ceiling_usage = "usage: cwceil priority\n";
 static void
 rtems_capture_cli_watch_ceiling (int                          argc,
                                  char**                       argv,
-                                 rtems_monitor_command_arg_t* command_arg,
-                                 boolean                      verbose)
+                                 const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                                 bool                         verbose __attribute__((unused)))
 {
   rtems_status_code   sc;
   int                 arg;
@@ -983,8 +981,8 @@ static char const * watch_floor_usage = "usage: cwfloor priority\n";
 static void
 rtems_capture_cli_watch_floor (int                          argc,
                                char**                       argv,
-                               rtems_monitor_command_arg_t* command_arg,
-                               boolean                      verbose)
+                               const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                               bool                         verbose __attribute__((unused)))
 {
   rtems_status_code   sc;
   int                 arg;
@@ -1084,20 +1082,20 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
   int                          arg;
   int                          trigger = 0; /* switch */
   rtems_capture_trigger_mode_t trigger_mode = rtems_capture_from_any;
-  rtems_boolean                trigger_set = 0;
-  rtems_boolean                is_from = 0;
+  bool                         trigger_set = false;
+  bool                         is_from = false;
   rtems_name                   name = 0;
   rtems_id                     id = 0;
-  rtems_boolean                valid_name = 0;
-  rtems_boolean                valid_id = 0;
+  bool                         valid_name = false;
+  bool                         valid_id = false;
   rtems_name                   from_name = 0;
   rtems_id                     from_id = 0;
-  rtems_boolean                from_valid_name = 0;
-  rtems_boolean                from_valid_id = 0;
+  bool                         from_valid_name = false;
+  bool                         from_valid_id = false;
   rtems_name                   to_name = 0;
   rtems_id                     to_id = 0;
-  rtems_boolean                to_valid_name = 0;
-  rtems_boolean                to_valid_id = 0;
+  bool                         to_valid_name = false;
+  bool                         to_valid_id = false;
 
   for (arg = 1; arg < argc; arg++)
   {
@@ -1118,18 +1116,18 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
     {
       if (!trigger_set)
       {
-        rtems_boolean found = 0;
-        int           t;
-        
+        bool found = false;
+        int  t;
+
         for (t = 0; t < RTEMS_CAPTURE_CLI_TRIGGERS_NUM; t++)
           if (strcmp (argv[arg], rtems_capture_cli_triggers[t].name) == 0)
           {
             trigger = t;
-            found = 1;
+            found = true;
             break;
           }
 
-        trigger_set = 1;
+        trigger_set = true;
 
         /*
          * If a trigger was not found assume the default and
@@ -1143,7 +1141,7 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
       {
         if (is_from)
           fprintf (stdout, "warning: extra 'from' ignored\n");
-        
+
         is_from = 1;
         continue;
       }
@@ -1158,7 +1156,7 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
         {
           if (!from_valid_name && !from_valid_id)
           {
-            from_valid_name = 1;
+            from_valid_name = true;
             from_name       = name;
           }
           else
@@ -1166,20 +1164,20 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
         }
         else if (!to_valid_name && !to_valid_id)
         {
-          to_valid_name = 1;
+          to_valid_name = true;
           to_name       = name;
         }
         else
           fprintf (stdout, "warning: extra arguments ignored\n");
       }
-          
+
       if (valid_id)
       {
         if (is_from)
         {
           if (!from_valid_name && !from_valid_id)
           {
-            from_valid_id = 1;
+            from_valid_id = true;
             from_id       = id;
           }
           else
@@ -1187,7 +1185,7 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
         }
         else if (!to_valid_name && !to_valid_id)
         {
-          to_valid_id = 1;
+          to_valid_id = true;
           to_id       = id;
         }
         else
@@ -1202,7 +1200,7 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
              rtems_capture_cli_triggers[trigger].name);
     return;
   }
-  
+
   if (!to_valid_name && !to_valid_id && !from_valid_name && !from_valid_id)
   {
     fprintf (stdout, trigger_set_usage);
@@ -1261,8 +1259,8 @@ rtems_capture_cli_trigger_worker (int set, int argc, char** argv)
 static void
 rtems_capture_cli_trigger_set (int                          argc,
                                char**                       argv,
-                               rtems_monitor_command_arg_t* command_arg,
-                               boolean                      verbose)
+                               const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                               bool                         verbose __attribute__((unused)))
 {
   rtems_capture_cli_trigger_worker (1, argc, argv);
 }
@@ -1279,8 +1277,8 @@ rtems_capture_cli_trigger_set (int                          argc,
 static void
 rtems_capture_cli_trigger_clear (int                          argc,
                                  char**                       argv,
-                                 rtems_monitor_command_arg_t* command_arg,
-                                 boolean                      verbose)
+                                 const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                                 bool                         verbose __attribute__((unused)))
 {
   rtems_capture_cli_trigger_worker (0, argc, argv);
 }
@@ -1297,11 +1295,11 @@ rtems_capture_cli_trigger_clear (int                          argc,
 static void
 rtems_capture_cli_trace_records (int                          argc,
                                  char**                       argv,
-                                 rtems_monitor_command_arg_t* command_arg,
-                                 boolean                      verbose)
+                                 const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                                 bool                         verbose __attribute__((unused)))
 {
   rtems_status_code       sc;
-  rtems_boolean           csv = 0;
+  bool                    csv = false;
   static int              dump_total = 22;
   int                     total;
   int                     count;
@@ -1314,19 +1312,19 @@ rtems_capture_cli_trace_records (int                          argc,
     if (argv[arg][0] == '-')
     {
       if (argv[arg][1] == 'c')
-        csv = 1;
+        csv = true;
       else
         fprintf (stdout, "warning: option -%c ignored\n", argv[arg][1]);
     }
     else
     {
-      int i;
-      int l;
+      size_t i;
+      size_t l;
 
       l = strlen (argv[arg]);
 
       for (i = 0; i < l; i++)
-        if (!isdigit (argv[arg][i]))
+        if (!isdigit ((unsigned char)argv[arg][i]))
         {
           fprintf (stdout, "error: not a number\n");
           return;
@@ -1353,7 +1351,7 @@ rtems_capture_cli_trace_records (int                          argc,
      * If we have no records then just exist. We still need to release
      * the reader lock.
      */
-    
+
     if (read == 0)
     {
       rtems_capture_release (read);
@@ -1361,13 +1359,13 @@ rtems_capture_cli_trace_records (int                          argc,
     }
 
     count = total < read ? total : read;
-    
+
     while (count--)
     {
       if (csv)
-        fprintf (stdout, "%08" PRIx32 ",%03" PRIu32
+        fprintf (stdout, "%08" PRIxPTR ",%03" PRIu32
                    ",%03" PRIu32 ",%04" PRIx32 ",%" PRId32 ",%" PRId32 "\n",
-                (uint32_t) rec->task,
+                (uintptr_t) rec->task,
                 (rec->events >> RTEMS_CAPTURE_REAL_PRIORITY_EVENT) & 0xff,
                 (rec->events >> RTEMS_CAPTURE_CURR_PRIORITY_EVENT) & 0xff,
                 (rec->events >> RTEMS_CAPTURE_EVENT_START),
@@ -1405,7 +1403,7 @@ rtems_capture_cli_trace_records (int                          argc,
     }
 
     count = total < read ? total : read;
-    
+
     if (count < total)
       total -= count;
     else
@@ -1428,11 +1426,11 @@ rtems_capture_cli_trace_records (int                          argc,
 static void
 rtems_capture_cli_flush (int                          argc,
                          char**                       argv,
-                         rtems_monitor_command_arg_t* command_arg,
-                         boolean                      verbose)
+                         const rtems_monitor_command_arg_t* command_arg __attribute__((unused)),
+                         bool                         verbose __attribute__((unused)))
 {
   rtems_status_code sc;
-  rtems_boolean     prime = 1;
+  bool              prime = true;
   int               arg;
 
   for (arg = 1; arg < argc; arg++)
@@ -1440,7 +1438,7 @@ rtems_capture_cli_flush (int                          argc,
     if (argv[arg][0] == '-')
     {
       if (argv[arg][1] == 'n')
-        prime = 0;
+        prime = false;
       else
         fprintf (stdout, "warning: option -%c ignored\n", argv[arg][1]);
     }
@@ -1611,7 +1609,7 @@ static rtems_monitor_command_entry_t rtems_capture_cli_cmds[] =
 rtems_status_code
 rtems_capture_cli_init (rtems_capture_timestamp timestamp)
 {
-  int cmd;
+  size_t cmd;
 
   capture_timestamp = timestamp;
 
