@@ -1,5 +1,12 @@
 /*
- *  $Id: semaphore.c,v 1.16 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2008.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -15,6 +22,7 @@
 #include <limits.h>
 
 #include <rtems/system.h>
+#include <rtems/config.h>
 #include <rtems/score/object.h>
 #include <rtems/posix/semaphore.h>
 #include <rtems/posix/time.h>
@@ -26,28 +34,26 @@
  *
  *  This routine initializes all semaphore manager related data structures.
  *
- *  Input parameters:
- *    maximum_semaphores - maximum configured semaphores
+ *  Input parameters:   NONE
  *
  *  Output parameters:  NONE
  */
 
-void _POSIX_Semaphore_Manager_initialization(
-  uint32_t   maximum_semaphores
-)
+void _POSIX_Semaphore_Manager_initialization(void)
 {
   _Objects_Initialize_information(
     &_POSIX_Semaphore_Information, /* object information table */
-    OBJECTS_POSIX_API,             /* object API */
-    OBJECTS_POSIX_SEMAPHORES,      /* object class */
-    maximum_semaphores             /* maximum objects of this class */,
+    OBJECTS_POSIX_API,          /* object API */
+    OBJECTS_POSIX_SEMAPHORES,   /* object class */
+    Configuration_POSIX_API.maximum_semaphores,
+                                /* maximum objects of this class */
     sizeof( POSIX_Semaphore_Control ),
                                 /* size of this object's control block */
-    TRUE,                       /* TRUE if names for this object are strings */
+    true,                       /* true if names for this object are strings */
     _POSIX_PATH_MAX             /* maximum length of each object's name */
 #if defined(RTEMS_MULTIPROCESSING)
     ,
-    FALSE,                      /* TRUE if this is a global object class */
+    false,                      /* true if this is a global object class */
     NULL                        /* Proxy extraction support callout */
 #endif
   );
