@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: ratemonident.c,v 1.9 2007/05/15 20:16:15 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -41,15 +41,15 @@
  */
 
 rtems_status_code rtems_rate_monotonic_ident(
-  rtems_name    name,
-  Objects_Id   *id
+  rtems_name  name,
+  rtems_id   *id
 )
 {
   Objects_Name_or_id_lookup_errors  status;
 
-  status = _Objects_Name_to_id(
+  status = _Objects_Name_to_id_u32(
     &_Rate_monotonic_Information,
-    (Objects_Name) name,
+    name,
     OBJECTS_SEARCH_LOCAL_NODE,
     id
   );
