@@ -1,4 +1,12 @@
 /**
+ * @file
+ *
+ * @ingroup ScoreProtHeap
+ *
+ * @brief Protected Heap Handler implementation.
+ */
+
+/*
  *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
@@ -6,7 +14,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pheapwalk.c,v 1.2 2007/09/07 19:39:25 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -16,19 +24,19 @@
 #include <rtems/system.h>
 #include <rtems/score/protectedheap.h>
 
-boolean _Protected_heap_Walk(
+bool _Protected_heap_Walk(
   Heap_Control *the_heap,
   int           source,
-  boolean       do_dump
+  bool          do_dump
 )
 {
-  boolean status;
+  bool    status;
 
   /*
    * If we are called from within a dispatching critical section,
    * then it is forbidden to lock a mutex.  But since we are inside
    * a critical section, it should be safe to walk it unlocked.
-   * 
+   *
    * NOTE: Dispatching is also disabled during initialization.
    */
   if ( !_Thread_Dispatch_disable_level ) {
