@@ -2,14 +2,14 @@
  *  Thread Queue Handler
  *
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: threadqflush.c,v 1.6 2005/01/27 05:57:05 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -41,7 +41,11 @@
 
 void _Thread_queue_Flush(
   Thread_queue_Control       *the_thread_queue,
+#if defined(RTEMS_MULTIPROCESSING)
   Thread_queue_Flush_callout  remote_extract_callout,
+#else
+  Thread_queue_Flush_callout  remote_extract_callout __attribute__((unused)),
+#endif
   uint32_t                    status
 )
 {
