@@ -18,10 +18,10 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: init.c,v 1.8 2004/11/22 10:38:22 ralf Exp $
+ *  $Id$
  */
 
-#define TEST_INIT
+#define CONFIGURE_INIT
 #include <tmacros.h>
 #include <stdio.h>
 #include <stdlib.h>
