@@ -2,14 +2,14 @@
  *  This test file is used to verify that the header files associated with
  *  invoking this function are correct.
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pthread11.c,v 1.11 2004/04/16 09:23:26 ralf Exp $
+ *  $Id$
  */
 
 #include <pthread.h>
@@ -18,6 +18,8 @@
 #error "RTEMS is supposed to have pthread_setschedparam"
 #endif
 
+void test( void );
+
 void test( void )
 {
   pthread_t           thread;
@@ -40,11 +42,11 @@ void test( void )
 
   param.sched_priority = 0;
 #ifdef _POSIX_SPORADIC_SERVER
-  param.ss_low_priority = 0;
-  param.ss_replenish_period.tv_sec = 0;
-  param.ss_replenish_period.tv_nsec = 0;
-  param.ss_initial_budget.tv_sec = 0;
-  param.ss_initial_budget.tv_nsec = 0;
+  param.sched_ss_low_priority = 0;
+  param.sched_ss_repl_period.tv_sec = 0;
+  param.sched_ss_repl_period.tv_nsec = 0;
+  param.sched_ss_init_budget.tv_sec = 0;
+  param.sched_ss_init_budget.tv_nsec = 0;
 #endif
 
   result = pthread_setschedparam( thread, policy, &param );
